==> apache-brpc-1.4.0-src.tar.gz: apache-brpc-1.4.0-src/community/oncall.md <==
# 值周工程师的职责如下

## 1. 每天查看github上brpc项目待处理的Pull Request和Issue列表，负责问题的处理
  *  包括标记issue，回复issue，关闭issue等；
  *  判断issue是否是长期Issue，如果是则标记为Pending
  *  判断Issue的类型，例如bug，enhancement, discussion等
  *  把issue分配到熟悉该模块的贡献者(可在微信群里询问谁来负责)

## 2. 轮值时间为一周
  *  即从周日早上到下周六晚上

## 3. 轮值结束需要
  *  编写值周report，并发送到dev@brpc.apache.org邮件群中
  *  提醒下一位轮值同学

## 4. 值周顺序如下
  * 朱佳顺 @zyearn
  * 李磊 @lorinlee
  * 王伟冰 @wwbmmm
  * 蔡道进 @cdjingit
  * 何磊 @TousakaRin
  * 刘帅 @serverglen

## 5. 值周记录如下

|  时间(月/日/年）   | 值周人  | 值周report|
|  ----  | ----  | --- |
| 06/21/2021 to 06/27/2021 | 李磊 | https://lists.apache.org/thread/czolsqo80jzsytqc7dp37knqwxnkymx1
| 06/28/2021 to 07/04/2021 | 蔡道进 | https://lists.apache.org/thread/c05fcjdjh7473ho1ylyl98mxscmnkbv0
| 07/05/2021 - 07/12/2021  | 何磊 | https://lists.apache.org/thread/hz1vn7358v5fslglg2cl4g8x0wtxy4lv
| 08/16/2021 - 08/22/2021  | 朱佳顺 | https://lists.apache.org/thread/g36jtjc3v75lfoc7m3ynzplgbqlsjjrd
| 08/23/2021 - 08/29/2021  | 李磊 | https://lists.apache.org/thread/2098ndgdy6fs2b1s8tywpmz47n5swh29
| 08/30/2021 - 09/05/2021  | 蔡道进 | https://lists.apache.org/thread/wjxdomg7fp75dc0n0rmh37bkwd8w7myv
| 09/06/2021 - 09/12/2021  | 何磊 | https://lists.apache.org/thread/cwjtocpjbqjgndog53rqw8gs6f9c0rmo
| 09/20/2021 - 09/26/2021  | 李磊 | https://lists.apache.org/thread/p779y43hogv7ftckc4cqx006gv9j65r8
| 09/27/2021 - 10/03/2021  | 蔡道进 | https://lists.apache.org/thread/ync12fx2dwjb2l3p4yck0kodmkgzz7wd
| 12/13/2021 - 12/19/2021  | 蔡道进 | https://lists.apache.org/thread/mvclsy79859mrbdso1xzm6y7yz3lg6w0
| 01/24/2022 - 02/06/2022  | 王伟冰 | https://lists.apache.org/thread/ttgqnw4hfw0qnb7swvnn2kxb5b9hkdbo
| 04/10/2022 - 04/16/2022  | 刘帅 | https://lists.apache.org/thread/0l67lqnw0l6rgfwkvhrc168prwr7fp60
| 04/17/2022 - 04/24/2022  | 朱佳顺| https://lists.apache.org/thread/xwkpyonndgtp8tq4c9v4yfowqx7fg9gl
| 04/25/2022 - 05/01/2022  | 李磊 | https://lists.apache.org/thread/cx7t1glptr7x7posxstsb1691h4m4mbl
| 05/02/2022 - 05/15/2022  | 王伟冰 | https://lists.apache.org/thread/tgyqkhh6fqgyzcn5d56kt46hk978wogx
| 06/06/2022 - 06/12/2022  | 何磊 | https://lists.apache.org/thread/s19p7ygnsj0bknfjvrh0wlf1mbgstxbk
| 06/13/2022 - 06/19/2022  | 刘帅 | https://lists.apache.org/thread/tvqjyz6rh7jb1zcclx0lh6zrcsf9ykxr
| 07/25/2022 - 07/31/2022  | 王伟冰 | https://lists.apache.org/thread/83scwkkfxrp6kkkoltbrn1fthfy3w0qz
| 08/08/2022 - 08/14/2022  | 何磊 | https://lists.apache.org/thread/jj16rzfh34yrt6o0xqfdz9wtdtzxzswq
| 08/15/2022 - 08/21/2022  | 刘帅 | https://lists.apache.org/thread/jp69sm7c8fs3dkdd828qk0fsojqwwz6h
| 09/05/2022 - 09/12/2022  | 王伟冰 | https://lists.apache.org/thread/4jjk2hxw9s2wskccclqb8fvpqxqffnlb
| 09/12/2022 - 09/18/2022  | 蔡道进| https://lists.apache.org/thread/8mo7zl0l2yrd8tp4v3kx86rnlyfk6wz4
| 09/19/2022 - 09/25/2022  | 何磊 | https://lists.apache.org/thread/qlkr7cmwow3ob47dt80tpx0zrgzg7bdm
| 09/26/2022 - 10/09/2022  | 刘帅 | https://lists.apache.org/thread/b0lwr8wyflmhqlnf0kkh1j30tgt5qw54
| 10/10/2022 - 10/16/2022  | 朱佳顺 | https://lists.apache.org/thread/y8sgbprxt21j6r0812dlftosfov6pbgk
| 10/17/2022 - 10/23/2022  | 李磊 | https://lists.apache.org/thread/qn2270p9qsrglkh7oy013ts1zk5rlhwx
| 10/24/2022 - 10/30/2022  | 王伟冰 | https://lists.apache.org/thread/k74155opmwmopgtsqo6p79z9q0f0sv8j
| 10/31/2022 - 11/06/2022  | 蔡道进 | https://lists.apache.org/thread/t4z49yt7ymp4vr5sms0m4cpoo94db4oz
| 11/14/2022 - 11/20/2022  | 刘帅 | https://lists.apache.org/thread/nq50fp79ox3follc7gxp814cvcqnmqzz
| 11/21/2022 - 11/27/2022  | 朱佳顺 | https://lists.apache.org/thread/57kzov5g3j4vv6l2zcyw0msm36qglc8k
| 11/28/2022 - 12/04/2022  | 李磊 | https://lists.apache.org/thread/92hbzcd662slj75v3ndjf69o1dgsnd6o
| 12/05/2022 - 12/11/2022  | 王伟冰 | https://lists.apache.org/thread/99o15h9hk5dd73jv8wyp49l8mbw0j611
| 12/19/2022 - 12/25/2022  | 何磊 | https://lists.apache.org/thread/g1stjjo1mc9ds47do6gosrw5k6wwb9mj
| 12/26/2022 - 01/01/2023  | 刘帅 | https://lists.apache.org/thread/3xw1gkobqmvr6oo375x3gsfcqvg80n23
| 01/02/2023 - 01/08/2023  | 朱佳顺 | https://lists.apache.org/thread/sm4f209c8ltols04gpmzo386b02dyc9s
| 01/09/2023 - 01/15/2023  | 李磊 | https://lists.apache.org/thread/fydjz4h88omsrb7fzw65wl64kh5r520s

==> apache-brpc-1.5.0-src.tar.gz: apache-brpc-1.5.0-src/community/oncall.md <==
# 值周工程师的职责如下

## 1. 每天查看github上brpc项目待处理的Pull Request和Issue列表，负责问题的处理
  *  包括标记issue，回复issue，关闭issue等；
  *  判断issue是否是长期Issue，如果是则标记为Pending
  *  判断Issue的类型，例如bug，enhancement, discussion等
  *  把issue分配到熟悉该模块的贡献者(可在微信群里询问谁来负责)

## 2. 轮值时间为一周
  *  即从周日早上到下周六晚上

## 3. 轮值结束需要
  *  编写值周report，并发送到dev@brpc.apache.org邮件群中
  *  提醒下一位轮值同学

## 4. 值周顺序如下
  * 朱佳顺 @zyearn
  * 李磊 @lorinlee
  * 王伟冰 @wwbmmm
  * 蔡道进 @cdjingit
  * 何磊 @TousakaRin
  * 刘帅 @serverglen
  * 胡希国 @Huixxi

## 5. 值周记录如下

|  时间(月/日/年）   | 值周人  | 值周report|
|  ----  | ----  | --- |
| 06/21/2021 to 06/27/2021 | 李磊 | https://lists.apache.org/thread/czolsqo80jzsytqc7dp37knqwxnkymx1
| 06/28/2021 to 07/04/2021 | 蔡道进 | https://lists.apache.org/thread/c05fcjdjh7473ho1ylyl98mxscmnkbv0
| 07/05/2021 - 07/12/2021  | 何磊 | https://lists.apache.org/thread/hz1vn7358v5fslglg2cl4g8x0wtxy4lv
| 08/16/2021 - 08/22/2021  | 朱佳顺 | https://lists.apache.org/thread/g36jtjc3v75lfoc7m3ynzplgbqlsjjrd
| 08/23/2021 - 08/29/2021  | 李磊 | https://lists.apache.org/thread/2098ndgdy6fs2b1s8tywpmz47n5swh29
| 08/30/2021 - 09/05/2021  | 蔡道进 | https://lists.apache.org/thread/wjxdomg7fp75dc0n0rmh37bkwd8w7myv
| 09/06/2021 - 09/12/2021  | 何磊 | https://lists.apache.org/thread/cwjtocpjbqjgndog53rqw8gs6f9c0rmo
| 09/20/2021 - 09/26/2021  | 李磊 | https://lists.apache.org/thread/p779y43hogv7ftckc4cqx006gv9j65r8
| 09/27/2021 - 10/03/2021  | 蔡道进 | https://lists.apache.org/thread/ync12fx2dwjb2l3p4yck0kodmkgzz7wd
| 12/13/2021 - 12/19/2021  | 蔡道进 | https://lists.apache.org/thread/mvclsy79859mrbdso1xzm6y7yz3lg6w0
| 01/24/2022 - 02/06/2022  | 王伟冰 | https://lists.apache.org/thread/ttgqnw4hfw0qnb7swvnn2kxb5b9hkdbo
| 04/10/2022 - 04/16/2022  | 刘帅 | https://lists.apache.org/thread/0l67lqnw0l6rgfwkvhrc168prwr7fp60
| 04/17/2022 - 04/24/2022  | 朱佳顺| https://lists.apache.org/thread/xwkpyonndgtp8tq4c9v4yfowqx7fg9gl
| 04/25/2022 - 05/01/2022  | 李磊 | https://lists.apache.org/thread/cx7t1glptr7x7posxstsb1691h4m4mbl
| 05/02/2022 - 05/15/2022  | 王伟冰 | https://lists.apache.org/thread/tgyqkhh6fqgyzcn5d56kt46hk978wogx
| 06/06/2022 - 06/12/2022  | 何磊 | https://lists.apache.org/thread/s19p7ygnsj0bknfjvrh0wlf1mbgstxbk
| 06/13/2022 - 06/19/2022  | 刘帅 | https://lists.apache.org/thread/tvqjyz6rh7jb1zcclx0lh6zrcsf9ykxr
| 07/25/2022 - 07/31/2022  | 王伟冰 | https://lists.apache.org/thread/83scwkkfxrp6kkkoltbrn1fthfy3w0qz
| 08/08/2022 - 08/14/2022  | 何磊 | https://lists.apache.org/thread/jj16rzfh34yrt6o0xqfdz9wtdtzxzswq
| 08/15/2022 - 08/21/2022  | 刘帅 | https://lists.apache.org/thread/jp69sm7c8fs3dkdd828qk0fsojqwwz6h
| 09/05/2022 - 09/12/2022  | 王伟冰 | https://lists.apache.org/thread/4jjk2hxw9s2wskccclqb8fvpqxqffnlb
| 09/12/2022 - 09/18/2022  | 蔡道进| https://lists.apache.org/thread/8mo7zl0l2yrd8tp4v3kx86rnlyfk6wz4
| 09/19/2022 - 09/25/2022  | 何磊 | https://lists.apache.org/thread/qlkr7cmwow3ob47dt80tpx0zrgzg7bdm
| 09/26/2022 - 10/09/2022  | 刘帅 | https://lists.apache.org/thread/b0lwr8wyflmhqlnf0kkh1j30tgt5qw54
| 10/10/2022 - 10/16/2022  | 朱佳顺 | https://lists.apache.org/thread/y8sgbprxt21j6r0812dlftosfov6pbgk
| 10/17/2022 - 10/23/2022  | 李磊 | https://lists.apache.org/thread/qn2270p9qsrglkh7oy013ts1zk5rlhwx
| 10/24/2022 - 10/30/2022  | 王伟冰 | https://lists.apache.org/thread/k74155opmwmopgtsqo6p79z9q0f0sv8j
| 10/31/2022 - 11/06/2022  | 蔡道进 | https://lists.apache.org/thread/t4z49yt7ymp4vr5sms0m4cpoo94db4oz
| 11/14/2022 - 11/20/2022  | 刘帅 | https://lists.apache.org/thread/nq50fp79ox3follc7gxp814cvcqnmqzz
| 11/21/2022 - 11/27/2022  | 朱佳顺 | https://lists.apache.org/thread/57kzov5g3j4vv6l2zcyw0msm36qglc8k
| 11/28/2022 - 12/04/2022  | 李磊 | https://lists.apache.org/thread/92hbzcd662slj75v3ndjf69o1dgsnd6o
| 12/05/2022 - 12/11/2022  | 王伟冰 | https://lists.apache.org/thread/99o15h9hk5dd73jv8wyp49l8mbw0j611
| 12/19/2022 - 12/25/2022  | 何磊 | https://lists.apache.org/thread/g1stjjo1mc9ds47do6gosrw5k6wwb9mj
| 12/26/2022 - 01/01/2023  | 刘帅 | https://lists.apache.org/thread/3xw1gkobqmvr6oo375x3gsfcqvg80n23
| 01/02/2023 - 01/08/2023  | 朱佳顺 | https://lists.apache.org/thread/sm4f209c8ltols04gpmzo386b02dyc9s
| 01/09/2023 - 01/15/2023  | 李磊 | https://lists.apache.org/thread/fydjz4h88omsrb7fzw65wl64kh5r520s
| 01/16/2023 - 01/29/2023  | 王伟冰 | https://lists.apache.org/thread/k5bb4pn2v23dksmwpwqphzlc4bd92ndr
| 01/30/2023 - 02/05/2023  | 蔡道进 | https://lists.apache.org/thread/4scwpdh163l92czm5pvc7ox78n44mrn4
| 02/13/2023 - 02/19/2023  | 刘帅 | https://lists.apache.org/thread/jwynp880hdhcfkqwq7thsm05y037wzy5
| 02/27/2023 - 03/05/2023  | 李磊 | https://lists.apache.org/thread/94ndftsvooydfnn8hdddv294pp0tfvdm
| 03/06/2023 - 03/12/2023  | 王伟冰 | https://lists.apache.org/thread/bv3qw5w8gj9xs576fplxqhktopkbk7md
| 03/27/2023 - 04/03/2023  | 刘帅 | https://lists.apache.org/thread/fk37cn8r5pd1y10vjvzvkl211b67vn4q
